@@ -1,25 +1,26 @@
+# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/lib/Data/Localize/Auto.pm 101877 2009-03-07T05:37:41.706351Z daisuke  $
 
 package Data::Localize::Auto;
 use Any::Moose;
 
-extends 'Data::Localize::Localizer';
+with 'Data::Localize::Localizer';
 
 __PACKAGE__->meta->make_immutable;
 
 no Any::Moose;
 
-sub get_lexicon {}
+sub register {}
 
 sub localize_for {
     my ($self, %args) = @_;
     my ($id, $args) = @args{ qw(id args) };
 
     my $value = $id;
-    if (Data::Localize::DEBUG()) {
+    if (&Data::Localize::DEBUG) {
         print STDERR "[Data::Localize::Auto]: localize_for - $id -> ",
             defined($value) ? $value : '(null)', "\n";
     }
-    return $self->format_string('auto', $value, @$args) if $value;
+    return $self->format_string($value, @$args) if $value;
     return ();
 }
 
@@ -37,8 +38,6 @@ Data::Localize::Auto - Fallback Localizer
 
 =head2 register
 
-=head2 get_lexicon
-
 Does nothing
 
 =head2 localize_for
